#
# spec file for package minidlna
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012 by Lars Vogdt <lars@linux-schulserver.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           minidlna
Version:        1.3.3
%define oversion 1.3.3
Release:        3.7
Summary:        DLNA compatible server
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Other
URL:            https://sourceforge.net/projects/minidlna/
Source0:        https://prdownloads.sourceforge.net/minidlna/%{name}-%{oversion}.tar.gz
# Systemd unit file
Source1:        %{name}.service
# tmpfiles configuration for the /run directory
Source2:        %{name}-tmpfiles.conf
# logrotate configuration
Source3:        minidlna_logrotate
# systemd-sysusers user configuration
Source4:        %{name}-user.conf
# VDR FIX thanks to Boris from openSuse
Patch1:         minidlna-vdr.diff
Patch2:         01-run-instead-of-var-run.patch
Patch3:         07-fix-multi-artist-album-handling.patch
Patch4:         08-Fix-testupnpdescgen-build.patch
Patch5:         10-do-not-close-socket-on-sighup.patch
Patch6:         13-spelling-and-typos.patch
Patch7:         15-thumbnails.patch
Patch8:         16-Add-compatibility-with-FFMPEG-7.0.patch
BuildRequires:  automake
BuildRequires:  flac-devel
BuildRequires:  libexif-devel
BuildRequires:  libid3tag-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libvorbis-devel
BuildRequires:  sqlite-devel
BuildRequires:  sysuser-shadow
BuildRequires:  sysuser-tools
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libffmpegthumbnailer)
Recommends:     logrotate
Provides:       ReadyMedia = %{version}
%sysusers_requires

%description
MiniDLNA (aka ReadyDLNA) is server software with the aim of being fully
compliant with DLNA/UPnP-AV clients.

%prep
%setup -q -n %{name}-%{oversion}
%autopatch -p1

%build
./autogen.sh

# Edit the default config file
sed -i 's/#log_dir=\/var\/log/#log_dir=\/var\/log\/minidlna/' \
  %{name}.conf

CFLAGS="%{optflags} -I/usr/include/ffmpeg"
%configure \
  --with-db-path=%{_localstatedir}/cache/%{name} \
  --with-log-path=%{_localstatedir}/log/%{name} \
  --enable-thumbnail \
  --enable-tivo

make %{?_smp_mflags}
%sysusers_generate_pre %{SOURCE4} minidlna

%install
%make_install
# install service file
install -D -m0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
# install tmpfiles configuration
install -D -m0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/%{name}.conf
#
install -d %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
# install logrotate file
install -D -m0644 %{SOURCE3} %{buildroot}/%{_sysconfdir}/logrotate.d/%{name}
# install cache directory
install -d -m0700 %{buildroot}%{_var}/cache/%{name}
# install log directory
install -d -m0700 %{buildroot}%{_var}/log/%{name}
# install manpages
install  -D -m0644 minidlna.conf.5 %{buildroot}/%{_mandir}/man5/minidlna.conf.5
install  -D -m0644 minidlnad.8 %{buildroot}/%{_mandir}/man8/minidlnad.8
# install example config
install  -D -m0644 minidlna.conf %{buildroot}/%{_sysconfdir}/minidlna.conf
# install sysusers config
install -D -m0644 %{SOURCE4} %{buildroot}%{_sysusersdir}/minidlna.conf

# find language dependent files
%find_lang minidlna

%pre -f minidlna.pre
%service_add_pre minidlna.service

%preun
%service_del_preun minidlna.service

%post
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf
%service_add_post minidlna.service

%postun
%service_del_postun minidlna.service

%files -f minidlna.lang
%license LICENCE* COPYING
%doc NEWS README TODO
%attr(-,minidlna,minidlna) %config(noreplace) %{_sysconfdir}/%{name}.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_mandir}/man5/*
%{_mandir}/man8/*
%{_sbindir}/*
%{_sysusersdir}/%{name}.conf
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/%{name}.service
%attr(0700,minidlna,minidlna) %{_var}/cache/%{name}
%attr(0700,minidlna,minidlna) %{_var}/log/%{name}

%changelog
* Wed Aug 21 2024 ro@suse.de
- add some of debian's patches and switch back to ffmpeg-7
- added patches:
  - 01-run-instead-of-var-run.patch
    use /run for runtime generated files
  - 07-fix-multi-artist-album-handling.patch
    fix for compilation albums
  - 08-Fix-testupnpdescgen-build.patch
    skip unneccessary lib when linking
  - 10-do-not-close-socket-on-sighup.patch
    no need to restart the interfaces when we just rescan
  - 13-spelling-and-typos.patch
    cleanup error message
  - 15-thumbnails.patch
    use ffmpegthumbnailer
  - 16-Add-compatibility-with-FFMPEG-7.0.patch
    fix build with current ffmpeg
- add br for pkgconfig(libffmpegthumbnailer)
* Wed Aug 21 2024 Manfred Hollstein <manfred.h@gmx.net>
- Don't use ffmpeg-7 as compilation of several files fails with
  error messages like:
  ...
  libav.h:177:36: error: ‘AVCodecParameters’ has no member named ‘channels’
  metadata.c:828:30: note: in expansion of macro ‘lav_channels’
  ...
* Sat Aug 19 2023 ecsos <ecsos@opensuse.org>
- Update to 1.3.3 (bsc#1222007)
  - Fixed HTTP chunk length parsing. (CVE-2023-33476)
  - Improved Dutch and Swedish translations.
  - Fixed directory symlink deletion handling.
* Sat Oct  1 2022 Dirk Müller <dmueller@suse.com>
- update to 1.3.2:
  * Improved DNS rebinding attack protection.
  * Added Samsung Neo QLED series (2021) support.
  * Added webm/rm/rmvb support.
  * Fixed a potential crash in SSDP request parsing.
  * Fixed a configure script failure on some platforms.
  * Protect against DNS rebinding attacks.
  * Fix an socket leakage issue on some platforms.
  * Minor bug fixes.
- drop minidlna-1.3.0-1.3.1.patch (upstream)
* Mon Mar  7 2022 ro@suse.de
- update to version 1.3.1 (bsc#1196814)
  - Fixed a potential crash in SSDP request parsing.
  - Fixed a configure script failure on some platforms.
  - Protect against DNS rebinding attacks. (CVE-2022-26505)
  - Fix an socket leakage issue on some platforms.
  - Minor bug fixes.
- added patch minidlna-1.3.0-1.3.1.patch as the new version
  was not tagged or released upstream
- added BR for automake to fix build and readd autogen call
- drop patch minidlna-multiple_definition.patch (upstreamed)
- add "su minidlna minidlna" to the logrotate config
* Wed Oct  6 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * minidlna.service
* Wed Dec  2 2020 Thorsten Kukuk <kukuk@suse.com>
- Use sysusers macros to create minidlna user
- Cleanup dependencies
- Don't hardrequire logrotate, we don't write log files anymore
* Tue Dec  1 2020 ro@suse.de
- update to version 1.3.0 (bsc#1179447)
  - Fixed some build warnings when building with musl.
  - Use $USER instead of $LOGNAME for the default friendly name.
  - Fixed build with GCC 10
  - Fixed some warnings from newer compilers
  - Disallow negative HTTP chunk lengths. [CVE-2020-28926]
  - Validate SUBSCRIBE callback URL. [CVE-2020-12695]
  - Fixed spurious warnings with ogg coverart
  - Fixed an issue with VLC where browse results would be truncated.
  - Fixed bookmarks on Samsung Q series
  - Added DSD file support.
  - Fixed potential stack smash vulnerability in getsyshwaddr on macOS.
  - Will now reload the log file on SIGHUP.
  - Worked around bad SearchCriteria from the Control4 Android app.
  - Increased max supported network addresses to 8.
  - Added forced alphasort capability.
  - Added episode season and number metadata support.
  - Enabled subtitles by default for unknown DLNA clients, and add enable_subtitles config option.
  - Fixed discovery when connected to certain WiFi routers.
  - Added FreeBSD kqueue support.
  - Added the ability to set the group to run as.
- remove upstreamed hunks from minidlna-multiple_definition.patch
- add zlib-devel to BuildRequires
* Mon Jun  8 2020 ro@suse.de
- add patch minidlna-multiple_definition.patch to fix
  multiple definition linker errors with recent gcc
  (from https://706916.bugs.gentoo.org/attachment.cgi?id=641058)
* Mon Dec 10 2018 olaf@aepfle.de
- Use pkgconfig(libav*) to refer to ffmpeg
* Mon Oct 22 2018 Ismail Dönmez <idonmez@suse.com>
- Fix a typo in spec file
- Use %%license
* Tue Dec 12 2017 ro@suse.de
- update service file: add reload action
* Mon Dec 11 2017 mpluskal@suse.com
- Cleanup spec file with spec-clener
* Mon Dec 11 2017 ro@suse.de
- reworked specfile based on fedora variant
- switched to systemd
- added patch minidlna-vdr.diff to serve vdr files
- update to 1.2.1 release
  - Added Movian client detection and subtitle support.
  - Fixed an issue with discovery on non-Linux systems.
  - Fixed Bonjour discovery compatibility with TiVo Bolt.
  - Fixed NFO file parsing, and added change monitoring support for them.
  - Added a workaround for video thumbnails on some Samsung clients.
  - Added DoS protection for event subscriptions.
  - Fixed content browsing issues with some Samsung TVs.
  - Improved non-destructive update scan support.
- update to 1.2.0 release
  - Add libavformat > 57 compatibility.
  - Add TiVo Bonjour discovery support using Avahi for Bolt.
  - Improve Samsung BD-J5500 support.
  - Add quirk to fix video playback on Hyundai TVs.
  - Add non-destructive update rescan support.
  - Enhance bookmark support to work with Kodi.
- update to 1.1.6 release
  - Add AllShare and Windows client detection.
  - Update support for LG2012 TV.
  - Fix Samsung bookmarking on magic containers.
  - Fix SQL error when moving captions.
  - Add wide_links config option.
  - Fix external subtitles on Samsung Series J.
  - Add string localization support for magic containers.
  - Rework NLS init to work with non-en_US locales.
- update to 1.1.5 release
  - Re-enable Samsung DCM10, which adds video bookmarks and "BasicView" support.
  - Allow SSDP M-SEARCH from other subnets.
  - Fix some nfo file character escaping.
  - Fix crash with >3 network interfaces.
  - Support rotation of monochrome JPEGs.
  - Handle cover art streams that come after the video stream.
  - Recognize new hard links with inotify.
  - Work around LG TV ordering bug.
  - Implement TiVo image PixelShape support.
  - Support thumbnail rotation.
  - Use "Album Artist" tag from AAC files.
  - Add Korean translations.
  - Fix handling of bad FLAC files.
- update to 1.1.4 release
  - Add magic container infrastructure.
  - Add magic containers for 50 recent items for each category.
  - Fix bad null termination in AAC parsing.
  - Fix requests for the last byte of a file, which affected MKV playback on Philips TV's.
  - Support 64-bit time_t values.
- update to 1.1.3 release
  - Enhance log level settings.
  - Fix Samsung browsing when root_container is set.
  - Add Clang compiling support.
  - Fix compiling on systems without iconv.
  - Add merge_media_dirs option, to revert to the old behavior.
  - Add Asus O!Play client support.
  - Fix Broken SSDP multicast membership addition.
  - Fix crash bug with an emtpy filter argument.
  - Accept SMI subtitles in addition to SRT.
  - Add BubbleUPnP detection and enable subtitle support.
  - Allow the user to specify an arbitrary root container.
  - Add libavcodec > 54 / libav 10 compatibility.
  - Get embedded cover art from video files with recent libavformat versions.
  - Disable Samsung DCM10 capability, as it breaks compatibility with new models.
  - Add subtitle support for NetFront™ Living Connect middleware-based clients.
- update to 1.1.2 release
  - Show client status on our basic presentation page.
  - Add a new force_sort_criteria option, to globally override the SortCriteria value sent by the client.
  - Fix a couple resource leaks.
  - Add configuration include file support.
  - Support DLNA/UPnP-AV searches issued by clients using the Grilo framework.
  - Fix some clients playing artwork instead of movie.
  - Fix bookmarks on Samsung Series E clients.
  - Add an extra folder level if there are multiple media locations.
  - Fix some multicast membership issues with changing network settings.
  - Make max number of children (connections) configurable.
  - Fix choppy playback with some file types on Panasonic clients by increasing the max connection limit.
- update to 1.1.1 release
  - Add network interface monitoring support on Linux.
  - Don't require a configured network interface to start up.
  - Fix some minor spec compliance issues.
- update to 1.1.0 release
  - Add support for other operating systems.
  - Switch to autoconf from our handcrafted genconfig.sh.
  - Add configuration option for UUID.
  - Add configuration option to specify the user to run as.
  - Add support for limiting a media dir to multiple media types.
  - Force a rescan if we detect a new or missing media_dir entry.
  - Fix crash caused by certain TiVo clients.
  - Fix crash bug on video files with some ffmpeg library versions.
  - Add support for TiVo MPEG-TS files.
  - Add some logging and forking tweaks to work better with systemd.
  - Validate or escape user input to prevent SQL injection.
  - Add forced sorting support for Panasonic devices.
* Fri Apr 13 2012 rabauke@opensuse.org
- update to 1.0.24 release
* Thu Sep  8 2011 vlewin@suse.com
- updated to version 1.0.22
- added rescan action to rcminildna file
  1.0.22 - Released 24-Aug-2011
  - -------------------------------
  - Add bookmark support for some Samsung TV's.
  - Fix a memory leak when certain model Samsung TV's or Roku devices are on the network.
  - Fix detection of Samsung Series D models.
  - Add WAV MIME workaround for Marantz Receivers and Roku SoundBridge.
  - Fix bitrate displayed on Microsoft PFS devices.
  - Fix a scanner crash when trying to scan image files with no read access.
  1.0.21 - Released 18-July-2011
  - -------------------------------
  - Fix a few issues with new libav/ffmpeg versions.
  - Fix FF/REW of AVI files on Samsung Series B TV's.
  - Fix a crash bug when playing music on TiVo.
  - Add the ability to change the root media container.
  - Add WAV/RIFF INFO tag parsing support for the most common tags.
  - Fix a crash bug with clients that request a large number of results.
* Fri Jul 15 2011 vlewin@novell.com
- Initial version
